ClassLoadingStrategy (py4j-java 0.10.9.7 API)

Package py4j.reflection

## Interface ClassLoadingStrategy

- All Known Implementing Classes:
    `CurrentThreadClassLoadingStrategy`, `RootClassLoadingStrategy`

      public interface ClassLoadingStrategy

  Strategy interface to load a class from a fully qualified name.

- - ### Method Summary

    All Methods Instance Methods Abstract Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `java.lang.Class<?>` | `classForName​(java.lang.String className)` |
    `java.lang.ClassLoader` | `getClassLoader()` |

- - ### Method Detail

    - #### classForName

          java.lang.Class<?> classForName​(java.lang.String className)
                                   throws java.lang.ClassNotFoundException

      Throws:
        `java.lang.ClassNotFoundException`

    - #### getClassLoader

          java.lang.ClassLoader getClassLoader()